=======
History
=======

1.0.0
-----
alpha python 3.7 version

0.1.11
------
polar fix for scatter plot plus variable defined marker size

0.1.11
------
initial box plot implementation (need to work on multi-series / color options)

0.1.10
------
expose additional options to CLI

0.1.9
-----
fix polar axis readin options on scatterplot

0.1.8
-----
proper labeling of max value when using -xticks/yticks

0.1.7
-----
bug in cl_plot colors

0.1.6
-----
improve graph formatting and bug fixes in scatter and histo

0.1.3
-----
add release to version bump

0.1.2
-----
first release on pypi

0.1.1
-----
remove dependency link from setup.py

0.1.0
-----
first stable release

0.0.1
-----
Initial setup of the directory

